PyMoa
=====

PyMoa is a framework for describing and running experiments.

For more information: https://matham.github.io/pymoa/index.html

To install https://matham.github.io/pymoa/installation.html

.. image:: https://img.shields.io/pypi/pyversions/pymoa.svg
    :target: https://pypi.python.org/pypi/pymoa/
    :alt: Supported Python versions

.. image:: https://img.shields.io/pypi/v/pymoa.svg
    :target: https://pypi.python.org/pypi/pymoa/
    :alt: Latest Version on PyPI

.. image:: https://coveralls.io/repos/github/matham/pymoa/badge.svg?branch=master
    :target: https://coveralls.io/github/matham/pymoa?branch=master
    :alt: Coverage status

.. image:: https://github.com/matham/pymoa/workflows/Python%20application/badge.svg
    :target: https://github.com/matham/pymoa/actions
    :alt: Github action status
